var searchData=
[
  ['dav1d_5fapi_0',['DAV1D_API',['../common_8h.html#a8e46f35f13caf963bb1320ec074639e2',1,'common.h']]],
  ['dav1d_5ferr_1',['DAV1D_ERR',['../common_8h.html#ab8bfe3b91c464d5f8f11413919eb16cd',1,'common.h']]],
  ['dav1d_5fmax_5fcdef_5fstrengths_2',['DAV1D_MAX_CDEF_STRENGTHS',['../headers_8h.html#a6d3a740e48c5f01c9f4c3fc508077d0a',1,'headers.h']]],
  ['dav1d_5fmax_5fframe_5fdelay_3',['DAV1D_MAX_FRAME_DELAY',['../dav1d_8h.html#ab58c9fcc5f207d2452618a36e79ddd27',1,'dav1d.h']]],
  ['dav1d_5fmax_5foperating_5fpoints_4',['DAV1D_MAX_OPERATING_POINTS',['../headers_8h.html#a3a6828cd51839b6fe1f3edc91e29916f',1,'headers.h']]],
  ['dav1d_5fmax_5fsegments_5',['DAV1D_MAX_SEGMENTS',['../headers_8h.html#a9168299c410dc89d022549b06b375d96',1,'headers.h']]],
  ['dav1d_5fmax_5fthreads_6',['DAV1D_MAX_THREADS',['../dav1d_8h.html#a1271d397b937de2bbf0149193030d2a8',1,'dav1d.h']]],
  ['dav1d_5fmax_5ftile_5fcols_7',['DAV1D_MAX_TILE_COLS',['../headers_8h.html#a8935432e8d0cf0da86cfaf5ff3ed8c89',1,'headers.h']]],
  ['dav1d_5fmax_5ftile_5frows_8',['DAV1D_MAX_TILE_ROWS',['../headers_8h.html#a782b8dfa823460b9140715513edce715',1,'headers.h']]],
  ['dav1d_5fnum_5fref_5fframes_9',['DAV1D_NUM_REF_FRAMES',['../headers_8h.html#ac3445b278a62f1964f391be8d2476962',1,'headers.h']]],
  ['dav1d_5fpicture_5falignment_10',['DAV1D_PICTURE_ALIGNMENT',['../picture_8h.html#aa60e80b4782a1e9c7ef89dcd957700f3',1,'picture.h']]],
  ['dav1d_5fprimary_5fref_5fnone_11',['DAV1D_PRIMARY_REF_NONE',['../headers_8h.html#ab62e142ad93daa0fc8f4df3df42e3632',1,'headers.h']]],
  ['dav1d_5frefs_5fper_5fframe_12',['DAV1D_REFS_PER_FRAME',['../headers_8h.html#a470e18d2e7a443f8f3d3edf6d2f757ce',1,'headers.h']]],
  ['dav1d_5ftotal_5frefs_5fper_5fframe_13',['DAV1D_TOTAL_REFS_PER_FRAME',['../headers_8h.html#a2cbcb5325c5f547a19a9ed3c743c3184',1,'headers.h']]]
];
